"""
Deduplicate

This script is used to deduplicate the dataset based on lower-cased title field.

minh.ha-duong@cnrs.fr, 2024 CC-BY-SA
"""

import json

IN_FILENAME = "CIRED_publications_normalized.json"
OUT_FILENAME = "CIRED_dataset.json"

with open(IN_FILENAME, "r", encoding="utf-8") as file:
    publications_data = json.load(file)

unique_publications = set()
deduplicated_publications = []
for pub in publications_data:
    if "title_s" in pub and pub["title_s"]:
        title = pub["title_s"][0].lower()  # We want case-insensitive comparison
        if title not in unique_publications:
            unique_publications.add(title)
            deduplicated_publications.append(pub)

with open(OUT_FILENAME, "w", encoding="utf-8") as file:
    json.dump(deduplicated_publications, file, ensure_ascii=False, indent=4)
