"""
Normalize Names

This script is used to normalize the names in the dataset.

minh.ha-duong@cnrs.fr, 2024 CC-BY-SA
"""

import json

IN_FILENAME = "CIRED_publications_translated.json"
OUT_FILENAME = "CIRED_publications_normalized.json"
MAPPING_FILENAME = "names_mapping.json"


# Load the publication data from the JSON file
def load_publications(json_file):
    with open(json_file, "r", encoding="utf-8") as file:
        publications = json.load(file)
    return publications


# Load the names mapping
def load_mapping(json_file):
    with open(json_file, "r", encoding="utf-8") as file:
        mapping = json.load(file)
    return mapping


# Update the names in the publication data with the normalized form
def update_publications(publications, mapping):
    for pub in publications:
        if "authFullName_s" in pub:
            for i, name in enumerate(pub["authFullName_s"]):
                if name in mapping.keys():
                    pub["authFullName_s"][i] = mapping[name]


# Save the updated publication data to a new JSON file
def save_updated_data(publications, output_file):
    with open(output_file, "w", encoding="utf-8") as file:
        json.dump(publications, file, ensure_ascii=False, indent=4)


# Main function
def main():
    publications = load_publications(IN_FILENAME)
    names_mapping = load_mapping(MAPPING_FILENAME)
    update_publications(publications, names_mapping)
    save_updated_data(publications, OUT_FILENAME)


if __name__ == "__main__":
    main()
